package com.miya.ali;

import com.miya.common.SessionClient;

import java.util.Arrays;
import java.util.List;

public class ReturnPayKafkaBinlogToHBase {


    private static final List<String> RDS_LIST = Arrays.asList("rds-binlog-mbox", "rds-binlog-37",
            "rds-binlog-hrhn_zx", "rds-binlog-hrhd_zx", "rds-binlog-qdm", "rds-binlog-watson_zx",
            "rds-binlog-hongkong", "rds-binlog-lawson", "rds-binlog-165", "rds-binlog-aeon", "rds-binlog-metro",
            "rds-binlog-yh", "rds-binlog-cdfy");


    public static String createSourceSql(String rds) {
        String CREATE_SOURCE_SQL_TEMPLATE = "CREATE TABLE " + rds.replace('-','_') + " (\n" +
                "saasid           STRING  ,\n" +
                "marketid         STRING  ,\n" +
                "operator_id      STRING  ,\n" +
                "out_id           STRING  ,\n" +
                "out_request_no   STRING  ,\n" +
                "paymentplatform  STRING  ,\n" +
                "serveicetype     STRING  ,\n" +
                "total_fee        STRING  ,\n" +
                "status           STRING  ,\n" +
                "trad_desc        STRING  ,\n" +
                "`date`           STRING  ,\n" +
                "miyadate         STRING  ,\n" +
                "retotal_fee      STRING  ,\n" +
                "cashier          STRING  ,\n" +
                "posbatch         STRING  ,\n" +
                "invoiceno        STRING  ,\n" +
                "fundbilllist     STRING  ,\n" +
                "seller_id        STRING  ,\n" +
                "trade_no         STRING  ,\n" +
                "orderfee         STRING  ,\n" +
                "rds_id           STRING  ,\n" +
                "rds_name         STRING  ,\n" +
                "currency         STRING  ,\n" +
                "settlementid     STRING  ,\n" +
                "trade_type       STRING  ,\n" +
                "deductionfee     STRING  ,\n" +
                "merchantdiscount STRING  ,\n" +
                "otherdescount    STRING    "+
                ") WITH (\n" +
                "  'connector' = 'kafka',\n" +
                "  'topic' = '"+rds+"',\n" +
                "  'properties.bootstrap.servers' = '10.0.1.227:9092,10.0.1.226:9092,10.0.1.228:9092',\n" +
                "  'properties.group.id' = 'flink-returnpay-binlog',\n" +
                "  'scan.startup.mode' = 'earliest-offset',\n" +
                "  'format' = 'canal-json' ,\n" +
                "  'canal-json.table.include' = 'returnpay' ,\n" +
                "  'canal-json.ignore-parse-errors' = 'true' \n" +
                ")";

        return CREATE_SOURCE_SQL_TEMPLATE;
    }


    public static String createSinkSql(){
        String CREATE_SINK_SQL = "CREATE TABLE huawei_hbase_sink_table (\n" +
                " rowkey STRING,\n" +
                " f ROW<saasid          STRING,\n" +
                "                        marketid         STRING  ,\n" +
                "                        operator_id      STRING  ,\n" +
                "                        out_id           STRING  ,\n" +
                "                        out_request_no   STRING  ,\n" +
                "                        paymentplatform  STRING  ,\n" +
                "                        serveicetype     STRING  ,\n" +
                "                        total_fee        STRING  ,\n" +
                "                        status           STRING  ,\n" +
                "                        trad_desc        STRING  ,\n" +
                "                        `date`             STRING  ,\n" +
                "                        miyadate         STRING,\n" +
                "                        retotal_fee      STRING  ,\n" +
                "                        cashier          STRING  ,\n" +
                "                        posbatch         STRING  ,\n" +
                "                        invoiceno        STRING  ,\n" +
                "                        fundbilllist     STRING  ,\n" +
                "                        seller_id        STRING  ,\n" +
                "                        trade_no         STRING  ,\n" +
                "                        orderfee         STRING  ,\n" +
                "                        rds_id           STRING  ,\n" +
                "                        rds_name         STRING  ,\n" +
                "                        currency         STRING  ,\n" +
                "                        settlementid     STRING  ,\n" +
                "                        trade_type       STRING  ,\n" +
                "                        deductionfee     STRING  ,\n" +
                "                        merchantdiscount STRING  ,\n" +
                "                        otherdescount    STRING  >,\n" +
                " PRIMARY KEY (rowkey) NOT ENFORCED\n" +
                ") WITH (\n" +
                " 'connector' = 'hbase-2.2',\n" +
                " 'table-name' = 'original:returnpay',\n" +
                " 'zookeeper.quorum' = '172.16.130.64:2181,172.16.128.15:2181,172.16.129.113:2181'" +
                ")";

        return CREATE_SINK_SQL;
    }


    public static String createJobSql() {
        StringBuilder stringBuilder = new StringBuilder();
        String CREATE_JOB_SQL = "INSERT INTO huawei_hbase_sink_table\n" +
                "SELECT " +
                "   CONCAT( CAST( (MOD(CAST(DATE_FORMAT(miyadate,'yyyyMMdd') AS INT),10)) AS  STRING ) , '~' , DATE_FORMAT(miyadate,'yyyyMMdd'),'~' , out_id) ," +
                "    ROW(" +
                "saasid           ,\n" +
                "marketid         ,\n" +
                "operator_id      ,\n" +
                "out_id           ,\n" +
                "out_request_no   ,\n" +
                "paymentplatform  ,\n" +
                "serveicetype     ,\n" +
                "total_fee        ,\n" +
                "status           ,\n" +
                "trad_desc        ,\n" +
                "`date`             ,\n" +
                "miyadate         ,\n" +
                "retotal_fee      ,\n" +
                "cashier          ,\n" +
                "posbatch         ,\n" +
                "invoiceno        ,\n" +
                "fundbilllist     ,\n" +
                "seller_id        ,\n" +
                "trade_no         ,\n" +
                "orderfee         ,\n" +
                "rds_id           ,\n" +
                "rds_name         ,\n" +
                "currency         ,\n" +
                "settlementid     ,\n" +
                "trade_type       ,\n" +
                "deductionfee     ,\n" +
                "merchantdiscount ,\n" +
                "otherdescount    \n" +
                "     ) FROM ( select * from  ( ";

        stringBuilder.append(CREATE_JOB_SQL).append( "select * from " + RDS_LIST.get(0).replace('-','_') );
        for (int i = 1; i < RDS_LIST.size(); i++) {
            stringBuilder.append (" union all select * from  " + RDS_LIST.get(i).replace('-','_'));
        }
        stringBuilder.append(" ) t )");
        return stringBuilder.toString();
    }


    public static void main(String[] args) throws Exception {
        SessionClient session = new SessionClient(new ReturnPayKafkaBinlogToHBase().getClass().getName(),"123.60.47.52", 8083, "streaming");


        for (String rds : RDS_LIST) {
            session.submitStatement(createSourceSql(rds)).getResults();
        }
        session.submitStatement(createSinkSql()).getResults();
        session.submitStatement(createJobSql()).getResults();


        session.close();

    }
}
